@@ -40,7 +40,10 @@ class MusicDisplayer(gtk.ScrolledWindow):
         self.g_pixmap = None
         self.m_width = self.m_height = 0
     def clear(self, numstaff=1):
-        self.m_engravers = [[],]*numstaff
+        if numstaff == 0:
+            self.m_engravers = []
+        else:
+            self.m_engravers = [[],]*numstaff
         self.g_d.queue_draw()
         self.g_pixmap = None
         dim = engravers.dimentions[20]
