@@ -31,14 +31,9 @@ class OSSSequencerSynth(oss_common.AbstractSynth):
             we ALWAYS have 16 channels, but the number
             of voices depend on your hardware.
     """
-    def __init__(self, device, devnum, card_info, verbose_init):
+    def __init__(self, device, devnum, verbose_init):
         oss_common.AbstractSynth.__init__(self, device, devnum, verbose_init)
-        self.m_card_info = card_info
         self.__tempo = (60, 4)
-        if self.m_card_info == 'awe':
-            solfege_c_midi.awe_set_channel_mode(self.m_devnum, 1);
-            # I thought the following line was necessary, but it is not...
-            #solfege_c_midi.awe_drum_channels(self.m_devnum, 512)
     def reset(self):
         # list of available voices, number depends on the soundcard.
         # AWE32 and GUS has 32, OPL3: 18, OPL2: 9
