@@ -44,7 +44,6 @@ del types
 
 STDC_HEADERS = _solfege_c_midi.STDC_HEADERS
 HAVE_FCNTL_H = _solfege_c_midi.HAVE_FCNTL_H
-HAVE_LINUX_AWE_VOICE_H = _solfege_c_midi.HAVE_LINUX_AWE_VOICE_H
 HAVE_SYS_IOCTL_H = _solfege_c_midi.HAVE_SYS_IOCTL_H
 HAVE_UNISTD_H = _solfege_c_midi.HAVE_UNISTD_H
 seq_bender = _solfege_c_midi.seq_bender
@@ -53,8 +52,6 @@ seq_stop_note = _solfege_c_midi.seq_stop_note
 seq_set_patch = _solfege_c_midi.seq_set_patch
 seq_delta_time = _solfege_c_midi.seq_delta_time
 seq_start_timer = _solfege_c_midi.seq_start_timer
-awe_set_channel_mode = _solfege_c_midi.awe_set_channel_mode
-awe_drum_channels = _solfege_c_midi.awe_drum_channels
 seqbuf_dump = _solfege_c_midi.seqbuf_dump
 sndctl_seq_nrsynths = _solfege_c_midi.sndctl_seq_nrsynths
 sndctl_seq_reset = _solfege_c_midi.sndctl_seq_reset
