@@ -250,9 +250,16 @@ It is also possible that the OS sound setup is incorrect.
             for msg in self.m_teachers[module].m_P.m_discards:
                 print >> sys.stderr, msg
         if not self.m_teachers[module].m_P:
-            for n in self.m_ui.box_dict[module].action_area.get_children():
-                n.set_sensitive(False)
+            # make the whole exercise insensitive if parsing
+            # the lesson file failed. We cannot run if parsing fails.
+            self.m_ui.box_dict[module].practise_box.set_sensitive(False)
+            self.m_ui.box_dict[module].config_box.set_sensitive(False)
+            self.m_ui.box_dict[module].action_area.set_sensitive(False)
             return
+        else:
+            self.m_ui.box_dict[module].practise_box.set_sensitive(True)
+            self.m_ui.box_dict[module].config_box.set_sensitive(True)
+            self.m_ui.box_dict[module].action_area.set_sensitive(True)
         self.m_ui.box_dict[module].on_start_practise()
         w = self.m_ui.g_ui_manager.get_widget("/Menubar/HelpMenu/PerExerciseHelp/HelpTheory")
         if w:
