@@ -78,13 +78,13 @@ class Teacher(abstract.Teacher):
         if self.m_question == bpm:
             self.stop_question()
             if self.q_status == self.QSTATUS_NEW:
-                self.m_statistics.add_correct(str(bpm))
+                self.m_statistics.add_correct(unicode(bpm))
             self.q_status = self.QSTATUS_SOLVED
             self.m_app.play_happy_sound()
             return 1
         else:
             if self.q_status == self.QSTATUS_NEW:
-                self.m_statistics.add_wrong(str(self.m_question), str(bpm))
+                self.m_statistics.add_wrong(str(self.m_question), unicode(bpm))
             self.q_status = self.QSTATUS_WRONG
             self.m_app.play_sad_sound()
     def end_practise(self):
