@@ -129,7 +129,7 @@ class Gui(abstract.LessonbasedGui):
                                  self.m_t.m_P.header.filldir)
             self.m_t.check_askfor()
             for question in self.m_t.m_P.iterate_questions_with_unique_names():
-                self.g_select_questions.add(question, 'normal')
+                self.g_select_questions.add(question)
         else:
             self.g_select_questions_category_box.hide()
             self.g_select_questions.initialize(0, 0)
