@@ -36,7 +36,7 @@ def get_learning_tree_list(debug):
     3. Full path to the learning tree.
     """
     trees = []
-    for cls, dir in (('solfege', 'learningtrees'),
+    for cls, dir in (('solfege', u'learningtrees'),
         ('user', os.path.join(filesystem.user_data(), "learningtrees"))):
         try:
             v = os.listdir(dir)
@@ -46,11 +46,11 @@ def get_learning_tree_list(debug):
             if cls == 'solfege':
                 fullpath = os.path.join("learningtrees", fn)
             else:
-                fullpath = os.path.join(filesystem.app_data(), "learningtrees", fn)
+                fullpath = os.path.join(filesystem.user_data(), "learningtrees", fn)
             trees.append((cls, fn, fullpath))
     if not debug:
         try:
-            trees.remove(('solfege', 'debugtree.txt', os.path.join('solfege', 'debugtree.txt')))
+            trees.remove(('solfege', 'debugtree.txt', os.path.join('learningtrees', 'debugtree.txt')))
         except ValueError:
             # The debugtree.txtfile is for some reason missing
             pass
@@ -645,6 +645,9 @@ class Window(gtk.Window):
         g = gtk.Button(stock='gtk-save-as')
         g.connect('clicked', self.on_save_as)
         hbox.pack_start(g, False)
+        g = gtk.Button(_("Delete learning tree"))
+        g.connect('clicked', self.on_delete_learning_tree)
+        hbox.pack_start(g, False)
         g = gtk.Button(stock='gtk-close')
         g.connect('clicked', self.close_window)
         hbox.pack_start(g, False)
@@ -863,6 +866,28 @@ class Window(gtk.Window):
                         self.m_model.set(child_iter, 0, self.m_app.lessonfile_manager.get(child, 'title'), 1, _("Lesson"))
             create_for_children(menu, None)
         self.g_treeview.set_model(self.m_model)
+    def on_delete_learning_tree(self, widget):
+        t, fn, fullpath = self.m_trees[self.g_trees.get_active()]
+        if t == 'solfege':
+            do_delete = gu.dialog_yesno(_("The file '%s' is part of GNU Solfege. Delete the file?") % fullpath)
+        else:
+            do_delete = gu.dialog_yesno(_("Delete the learning tree '%s'") % fullpath)
+        if do_delete:
+            try:
+                os.remove(fullpath)
+            except OSError, e:
+                self.m_app.m_ui.display_error_message2(_("Failed to delete file"), unicode(str(e), sys.getfilesystemencoding(), 'replace'))
+            else:
+                self.fill_trees_combo()
+                # We try to find the default learning tree and make that active.
+                # If not, we just use the first tree.
+                i = -1
+                for idx, s in enumerate(self.m_trees):
+                    if s[0] == 'solfege' and s[1] == u'learningtree.txt':
+                        i = idx
+                if i == -1:
+                    i = 0
+                self.g_trees.set_active(i)
     def on_new(self, widget):
         if self.m_tree.m_modified:
             if gu.dialog_yesno(_("The file is not saved. Save before changing?"), self):
@@ -897,14 +922,14 @@ class Window(gtk.Window):
                 if path or (not filename):
                     self.g_filename_description.set_text(donot_str)
                     self.g_filename_description.show()
-                elif os.path.exists(os.path.join(filesystem.app_data(), 'learningtrees', filename)):
+                elif os.path.exists(os.path.join(filesystem.user_data(), 'learningtrees', filename)):
                     self.g_filename_description.set_text(_("The file already exists."))
                     self.g_filename_description.show()
                 else:
                     try:
-                        if not os.path.exists(os.path.join(filesystem.app_data(), 'learningtrees')):
-                            os.makedirs(os.path.join(filesystem.app_data(), 'learningtrees'))
-                        f = open(os.path.join(filesystem.app_data(), 'learningtrees', filename), 'w')
+                        if not os.path.exists(os.path.join(filesystem.user_data(), 'learningtrees')):
+                            os.makedirs(os.path.join(filesystem.user_data(), 'learningtrees'))
+                        f = open(os.path.join(filesystem.user_data(), 'learningtrees', filename), 'w')
                         f.write("""
 [ # toplevel list
   2, # learning tree file format version
@@ -1273,7 +1298,7 @@ class Window(gtk.Window):
             self._load_file(os.path.join("learningtrees", filename))
         else:
             assert place == 'user'
-            self._load_file(os.path.join(filesystem.app_data(), 'learningtrees', filename))
+            self._load_file(os.path.join(filesystem.user_data(), 'learningtrees', filename))
         self.set_trees_combo(place, filename)
         # 
         if place == 'solfege':
