@@ -223,7 +223,6 @@ lessonfile_functions = {
         'mma': (False, lambda *v: Mma(*v)),
         'progressionlabel': (False, lambda s: LabelObject("progressionlabel", s)),
         'pangomarkup': (False, lambda s: LabelObject("pangomarkup", s)),
-        'plabel': (False, lambda a, b, c: LabelObject("plabel", (a, b, c))),
         'rnc': (False, lambda s: LabelObject("rnc", s)),
         'chordname': (False, lambda s: LabelObject("chordname", s)),
 }
@@ -1461,7 +1460,7 @@ class ElembuilderLessonfile(QuestionsLessonfile):
         # We need the name variable for statistics
         self.discard_questions_without_name()
         # This loop let us use normal strings and lesson file functions
-        # like plabel and pangomarkup as element labels.
+        # like pangomarkup as element labels.
         for question in self.m_questions:
             if [e for e in question['elements'] if type(e) in (istr, LabelObject)]:
                 v = []
