@@ -22,7 +22,7 @@ import gtk
 
 import gu
 import runtime
-import configureoutput
+import buildinfo
 import pmwiki
 import utils
 import cfg
@@ -122,7 +122,8 @@ class ReportBugWindow(gtk.Dialog):
             "Submitter: %s\\\\" % email,
             "Long desciption: %s\n" % description,
             "||border=1",
-            "|| Solfege version||%s ||" % configureoutput.VERSION_STRING,
+            "|| Solfege version||%s ||" % buildinfo.VERSION_STRING,
+            "|| Bzr revision info ||%s ||" % buildinfo.get_bzr_revision_info_pmwiki(),
             "|| runtime.use_gtkhtml2||%s ||" % runtime.use_gtkhtml2(),
             "|| gtk.pygtk_version||%s ||" % str(gtk.pygtk_version),
             "|| gtk||%s ||" % gtk,
