@@ -18,6 +18,7 @@ import sys
 import gtk
 import cfg
 import gu
+import lessonfilegui
 
 
 class AbstractQuestionNameTable(gtk.Table, cfg.ConfigUtils):
@@ -83,7 +84,7 @@ class QuestionNameButtonTable(AbstractQuestionNameTable):
         for n, button in self.m_button_dict.items():
             button.set_sensitive(
                 self.m_name_list.index(n) in self.get_list('ask_for_names'))
-    def add(self, question, style, callback):
+    def add(self, question, callback):
         """add a button and set up callback function.
         there should not be created more than one button with the same
         (c locale) name.
@@ -99,10 +100,7 @@ class QuestionNameButtonTable(AbstractQuestionNameTable):
         self.m_name_list.append(question.name.cval)
         b.set_data('cname', question.name.cval)
         b.set_sensitive(question.active)
-        if style == 'progression':
-            b.add(gu.HarmonicProgressionLabel(question.name, 'center'))
-        else:
-            b.add(gtk.Label(question.name))
+        b.add(lessonfilegui.new_labelobject(question.name))
         b.show_all()
         self.attach(b, self.m_x, self.m_x+1, self.m_y, self.m_y+1)
         b.connect('clicked', callback)
@@ -124,7 +122,7 @@ class QuestionNameCheckButtonTable(AbstractQuestionNameTable):
             return
         for question in self.m_t.m_P.m_questions:
             question.active = self.m_name_list.index(question.name.cval) in self.get_list('ask_for_names')
-    def add(self, question, labelformat):
+    def add(self, question):
         """add a button and set up callback function.
         there should not be created more than one button with the same
         (c locale) name.
@@ -141,12 +139,7 @@ class QuestionNameCheckButtonTable(AbstractQuestionNameTable):
         b.set_active(question.active)
         b.connect('toggled', self.on_checkbutton_toggled)
         b.set_data('cname', question.name.cval)
-        if labelformat == 'progression':
-            b.add(gu.HarmonicProgressionLabel(question.name, 'center'))
-        elif labelformat == 'normal':
-            b.add(gtk.Label(question.name))
-        else:
-            print >> sys.stderr, "labelformat=%s is not valid" % labelformat
+        b.add(lessonfilegui.new_labelobject(question.name))
         b.show_all()
         self.attach(b, self.m_x, self.m_x+1, self.m_y, self.m_y+1)
         self.conditional_newline()
