@@ -636,7 +636,24 @@ class TestLabelObject(unittest.TestCase):
             ("Imaj7-V7", [('I', 'maj', '7', '-'), ('V', '', '7', '')]),
             ("Imaj7  -IIm9", [('I', 'maj', '7', '  -'), ('II', 'm', '9', '')]),
                 ):
-            self.assertEquals(rn_markup_tokenizer(s), v, (rn_markup_tokenizer(s), v))
+            self.assertEquals(rnc_markup_tokenizer(s), v, (rnc_markup_tokenizer(s), v))
+
+    def test_chordname_markup(self):
+        for s, v in (
+            ("cis4", [('cis', '4', '', '')]),
+            ('gmaj7', [('g', 'maj7', '', '')]),
+            ('gesmaj7:9b5', [('ges', 'maj7', '9b5', '')]),
+            ('g/g', [('g', '', '', 'g')]),
+            ('g', [('g', '', '', '')]),
+            ('gm', [('g', 'm', '', '')]),
+            ('g:7', [('g', '', '7', '')]),
+            ('gm:7', [('g', 'm', '7', '')]),
+            ('d/fis', [('d', '', '', 'fis')]),
+            ('gm/f', [('g', 'm', '', 'f')]),
+            ('gm:7/d', [('g', 'm', '7', 'd')]),
+            ('gm:13/5-/d', [('g', 'm', '13/5-', 'd')]),
+            ):
+            self.assertEquals(chordname_markup_tokenizer(s), v)
 
 
 suite = unittest.makeSuite(TestParser)
